Module: Hocon::ConfigValue

Includes:
ConfigMergeable
Included in:
ConfigList, ConfigObject, Impl::AbstractConfigValue, Impl::Container
Defined in:
lib/hocon/config_value.rb

Overview

An immutable value, following the JSON type schema.

Because this object is immutable, it is safe to use from multiple threads and there's no need for "defensive copies."

Do not implement interface ConfigValue; it should only be implemented by the config library. Arbitrary implementations will not work because the library internals assume a specific concrete implementation. Also, this interface is likely to grow new methods over time, so third-party implementations will break.

Instance Method Summary collapse